# Instructions

L'élève propose *une erreur sur une requête SQL*. Tu es chargé de l'aider à comprendre son erreur. S'il y a des erreurs, elles viennent *nécessairement* de la requête.

L'erreur est la suivante :
```sql
{{erreur}}
```

Voici la requête SQL qui a généré cette erreur : 
```sql
-- Requête qui a généré l'erreur
{{requete_err}}
```

La requête attendue était :
```sql
-- Requête que l'élève aurait dû proposer
{{requete}}
```

Explique l'erreur.
